@@ -206,7 +206,7 @@ def extract_script(embedded_hex):
     return ''
 
 
-def find_device(preferdisk=None, sizeCheck=None):
+def find_device(preferdisk=None):
     """
     Returns a path on the filesystem that represents the plugged in BBC
     micro:bit that is to be flashed. If no micro:bit is found, it returns
@@ -275,11 +275,6 @@ def find_device(preferdisk=None, sizeCheck=None):
                     pathName = get_volume_name(path)
                     if pathName in defaultPathList:
                         return path
-                    elif sizeCheck != None:
-                        sizeCheck = eval(sizeCheck.replace('M', '*1024*1024'))
-                        total, used, free = shutil.disk_usage(path)
-                        if abs(total - sizeCheck) < 0x20000:
-                            return path
                     elif preferdisk != None:
                         if preferdisk == pathName:
                             return path
@@ -371,7 +366,7 @@ def flash(path_to_python=None, paths_to_microbits=None,
     else:
         return (-2, 'Unable to find micro:bit. Is it plugged in?')
 
-def copyfileobj(fsrc, fdst, callback, total, length=4*1024):
+def copyfileobj(fsrc, fdst, callback, total, length=16*1024):
     copied = 0
     while True:
         buf = fsrc.read(length)
@@ -380,9 +375,6 @@ def copyfileobj(fsrc, fdst, callback, total, length=4*1024):
         fdst.write(buf)
         copied += len(buf)
         callback(copied, total)
-        # this is for mac, cache ENXIO in runtime
-        fdst.flush()
-        os.fsync(fdst)
 
 def copyHex(path_to_hex, callback):
     # todo: support uf2 borads other than microbits
@@ -419,8 +411,8 @@ def copyHex(path_to_hex, callback):
     else:
         return (-1, 'Unable to find target')
 
-def getDisk(disk_filter, size=None):
-    found_microbit = find_device(disk_filter, size)
+def getDisk(disk_filter):
+    found_microbit = find_device(disk_filter)
     return found_microbit
 
 def extract(path_to_hex, output_path=None):
